@@ -25,11 +25,13 @@ from pyzm.helpers.Monitors import Monitors
 from pyzm.helpers.Events import Events
 from pyzm.helpers.States import States
 from pyzm.helpers.Configs import Configs
+import pyzm.helpers.globals as g
+
 
 
 
 class ZMApi (Base):
-    def __init__(self,options={}, logger=None):
+    def __init__(self,options={}):
         '''
         Options is a dict with the following keys:
 
@@ -38,18 +40,14 @@ class ZMApi (Base):
             - user - username (don't specify if no auth)
             - password - password (don't specify if no auth)
             - disable_ssl_cert_check - if True will let you use self signed certs
-            - logger - (OPTIONAL) function used for logging. If none specified, a simple logger will be used that prints to console. You could instantiate and connect the :class:`pyzm.helpers.ZMLog` module here if you want to use ZM's logging.
-
             Note: you can connect your own customer logging class to the API in which case all modules will use your custom class. Your class will need to implement some methods for this to work. See :class:`pyzm.helpers.Base.SimpleLog` for method details.
         '''
         
-        l = logger or options.get('logger')
-        super().__init__(l)
         self.api_url = options.get('apiurl')
         self.portal_url = options.get('portalurl')
         if not self.portal_url and self.api_url.endswith('/api'):
             self.portal_url = self.api_url[:-len('/api')] 
-            self.logger.Debug (2,'Guessing portal URL is: {}'.format(self.portal_url))
+            g.logger.Debug (2,'Guessing portal URL is: {}'.format(self.portal_url))
 
         self.options = options
         
@@ -66,7 +64,7 @@ class ZMApi (Base):
         self.session = requests.Session()
         if options.get('disable_ssl_cert_check', True):
             self.session.verify = False
-            self.logger.Debug (2, 'API SSL certificate check has been disbled')
+            g.logger.Debug (2, 'API SSL certificate check has been disbled')
             from urllib3.exceptions import InsecureRequestWarning
             requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
         self.api_version = None
@@ -76,10 +74,8 @@ class ZMApi (Base):
      
         self._login()
      
-        #self.Monitors = Monitors(logger=options.get('logger'),api=self)
         self.Monitors = None
         self.Events = None
-        #self.Configs = Configs(logger=options.get('logger'), api=self)
         self.Configs = None
     def _versiontuple(self,v):
         #https://stackoverflow.com/a/11887825/1361529
@@ -132,7 +128,7 @@ class ZMApi (Base):
             return
         tr = (self.access_token_datetime - datetime.datetime.now()).total_seconds()
         if (tr >= 60*5): # 5 mins grace 
-            self.logger.Debug(3, 'No need to relogin as access token still has {} minutes remaining'.format(tr/60))
+            g.logger.Debug(3, 'No need to relogin as access token still has {} minutes remaining'.format(tr/60))
             return
         else:
             self._relogin()
@@ -148,10 +144,10 @@ class ZMApi (Base):
 
 
             if (tr >= 60 * 5): # 5 mins grace
-                self.logger.Debug(2, 'Going to use refresh token as it still has {} minutes remaining'.format(tr/60))
+                g.logger.Debug(2, 'Going to use refresh token as it still has {} minutes remaining'.format(tr/60))
                 self.options['token'] = self.refresh_token
             else:
-                self.logger.Debug (1, 'Refresh token only has {}s of lifetime, going to use user/pass'.format(tr))
+                g.logger.Debug (1, 'Refresh token only has {}s of lifetime, going to use user/pass'.format(tr))
                 self.options['token'] = None
         self._login()
 
@@ -164,26 +160,26 @@ class ZMApi (Base):
         try:
             url = self.api_url+'/host/login.json'
             if self.options.get('token'):
-                self.logger.Debug(1,'Using token for login [{}]'.format(self.options.get('token')))
+                g.logger.Debug(1,'Using token for login [{}]'.format(self.options.get('token')))
                 data = {'token':self.options.get('token')}
                 self.auth_enabled = True
 
             elif self.options.get('user') and self.options.get('password'):
-                self.logger.Debug (1,'using username/password for login')
+                g.logger.Debug (1,'using username/password for login')
                 data={'user': self.options.get('user'),
                     'pass': self.options.get('password')
                 }
                 self.auth_enabled = True
 
             else:
-                self.logger.Debug(1,'Not using auth')
+                g.logger.Debug(1,'Not using auth')
                 self.auth_enabled = False
                 data = {}
                 url = self.api_url + '/host/getVersion.json'
                 
             r = self.session.post(url, data=data)
             if r.status_code == 401 and self.options.get('token') and self.auth_enabled:
-                self.logger.Debug (1, 'Token auth with refresh failed. Likely revoked, doing u/p login')
+                g.logger.Debug (1, 'Token auth with refresh failed. Likely revoked, doing u/p login')
                 self.options['token'] = None
                 data={'user': self.options.get('user'),
                     'pass': self.options.get('password')
@@ -198,20 +194,20 @@ class ZMApi (Base):
             self.zm_version = rj.get('version')
             if self.auth_enabled:
                 if (self._versiontuple(self.api_version) >= self._versiontuple('2.0')):
-                    self.logger.Debug(2,'Using new token API')
+                    g.logger.Debug(2,'Using new token API')
                     self.access_token = rj.get('access_token','')
                     if rj.get('refresh_token'):
                         self.refresh_token = rj.get('refresh_token')
                     if (rj.get('access_token_expires')):
                         self.access_token_expires = int(rj.get('access_token_expires'))
                         self.access_token_datetime = datetime.datetime.now() + datetime.timedelta(seconds = self.access_token_expires)
-                        self.logger.Debug (1, 'Access token expires on:{} [{}s]'.format(self.access_token_datetime, self.access_token_expires))
+                        g.logger.Debug (1, 'Access token expires on:{} [{}s]'.format(self.access_token_datetime, self.access_token_expires))
                     if (rj.get('refresh_token_expires')):
                         self.refresh_token_expires = int(rj.get('refresh_token_expires'))
                         self.refresh_token_datetime = datetime.datetime.now() + datetime.timedelta(seconds = self.refresh_token_expires)
-                        self.logger.Debug (1, 'Refresh token expires on:{} [{}s]'.format(self.refresh_token_datetime, self.refresh_token_expires))
+                        g.logger.Debug (1, 'Refresh token expires on:{} [{}s]'.format(self.refresh_token_datetime, self.refresh_token_expires))
                 else:
-                    self.logger.Info('Using old credentials API. Recommended you upgrade to token API')
+                    g.logger.Info('Using old credentials API. Recommended you upgrade to token API')
                     self.legacy_credentials = rj.get('credentials')
                     if (rj.get('append_password') == '1'):
                         self.legacy_credentials = self.legacy_credentials + self.options.get('password')
@@ -219,7 +215,7 @@ class ZMApi (Base):
             #print (vars(self.session))
 
         except requests.exceptions.HTTPError as err:
-            self.logger.Error('Got API login error: {}'.format(err), 'error')
+            g.logger.Error('Got API login error: {}'.format(err), 'error')
             self.authenticated = False
             raise err
 
@@ -230,7 +226,7 @@ class ZMApi (Base):
             r = self._make_request(url)
             self.zm_tz = r.get('tz')
         except requests.exceptions.HTTPError as err:
-            self.logger.Error ('Timezone API not found, relative timezones will be local time')
+            g.logger.Error ('Timezone API not found, relative timezones will be local time')
 
     def get_apibase(self):
         return self.api_url
@@ -268,7 +264,7 @@ class ZMApi (Base):
                 url += qchar + self.legacy_credentials
                 
         try:
-            self.logger.Debug(4,'make_request called with url={} payload={} type={} query={}'.format(url,payload,type,query))
+            g.logger.Debug(4,'make_request called with url={} payload={} type={} query={}'.format(url,payload,type,query))
             if type=='get':
                 r = self.session.get(url, params=query)
 
@@ -279,7 +275,7 @@ class ZMApi (Base):
             elif type=='delete':
                 r = self.session.delete(url, data=payload, params=query)
             else:
-                self.logger.Error('Unsupported request type:{}'.format(type))
+                g.logger.Error('Unsupported request type:{}'.format(type))
                 raise ValueError ('Unsupported request type:{}'.format(type))
             #print (url, params)
             #r = requests.get(url, params=params)
@@ -295,33 +291,33 @@ class ZMApi (Base):
             else:
                 # A non 0 byte response will usually mean its an image eid request that needs re-login
                 if r.headers.get('content-length') != '0':
-                    self.logger.Debug(4, 'Raising RELOGIN ValueError')
+                    g.logger.Debug(4, 'Raising RELOGIN ValueError')
                     raise ValueError ("RELOGIN")
                 else:
                     # ZM returns 0 byte body if index not found
-                    self.logger.Debug(4, 'Raising BAD_IMAGE ValueError as Content-Length:0')
+                    g.logger.Debug(4, 'Raising BAD_IMAGE ValueError as Content-Length:0')
                     raise ValueError ("BAD_IMAGE")
                 #return r.text
 
         except requests.exceptions.HTTPError as err:
-            self.logger.Debug(1, 'HTTP error: {}'.format(err))
+            g.logger.Debug(1, 'HTTP error: {}'.format(err))
             if err.response.status_code == 401 and reauth:
-                self.logger.Debug (1, 'Got 401 (Unauthorized) - retrying login once')
+                g.logger.Debug (1, 'Got 401 (Unauthorized) - retrying login once')
                 self._relogin()
-                self.logger.Debug (1,'Retrying failed request again...')
+                g.logger.Debug (1,'Retrying failed request again...')
                 return self._make_request(url, query, payload, type, reauth=False)
             elif err.response.status_code == 404:
                 # ZM returns 404 when an image cannot be decoded
-                self.logger.Debug(4, 'Raising BAD_IMAGE ValueError for a 404')
+                g.logger.Debug(4, 'Raising BAD_IMAGE ValueError for a 404')
                 raise ValueError ("BAD_IMAGE")
         except ValueError as err:
             err_msg = '{}'.format(err)
             if err_msg == "RELOGIN":
                 if reauth:
-                    self.logger.Debug(1, 'Got ValueError access error: {}'.format(err))
-                    self.logger.Debug (1, 'Retrying login once')
+                    g.logger.Debug(1, 'Got ValueError access error: {}'.format(err))
+                    g.logger.Debug (1, 'Retrying login once')
                     self._relogin()
-                    self.logger.Debug (1,'Retrying failed request again...')
+                    g.logger.Debug (1,'Retrying failed request again...')
                     return self._make_request(url, query, payload, type, reauth=False)
                 else:
                     raise err
@@ -346,7 +342,7 @@ class ZMApi (Base):
             list of :class:`pyzm.helpers.Monitor`: list of monitors 
         """
         if options.get('force_reload') or not self.Monitors:
-            self.Monitors = Monitors(logger=self.logger,api=self)
+            self.Monitors = Monitors(api=self)
         return self.Monitors
 
     def events(self,options={}):
@@ -372,7 +368,7 @@ class ZMApi (Base):
         Returns:
             list of :class:`pyzm.helpers.Event`: list of events that match criteria
         """
-        self.Events = Events(logger=self.logger,api=self, options=options)
+        self.Events = Events(api=self, options=options)
         return self.Events
 
     def states(self, options={}):
@@ -384,7 +380,7 @@ class ZMApi (Base):
         Returns:
             list of  :class:`pyzm.helpers.State`: list of states
         """
-        self.States = States(logger=self.logger,api=self)
+        self.States = States(api=self)
         return self.States
     
     def restart(self):
@@ -440,5 +436,5 @@ class ZMApi (Base):
             :class:`pyzm.helpers.Configs`: ZM configs
         """
         if options.get('force_reload') or not self.Configs:
-            self.Configs = Configs(logger=self.logger,api=self)
+            self.Configs = Configs(api=self)
         return self.Configs
