@@ -17,13 +17,16 @@ import cv2
 import traceback
 from shapely.geometry import Polygon
 import copy
+import pyzm.helpers.globals as g
+import pickle
+import os
+
 
 class DetectSequence(Base):
-    def __init__(self, logger=None, options={}):
+    def __init__(self, options={}, global_config={}):
         """Initializes ML entry point with various parameters
 
         Args:
-            - logger (object, optional): log handler to use
             - options (dict): Variety of ML options. Best described by an example as below
             
                 ::
@@ -117,13 +120,11 @@ class DetectSequence(Base):
                     } # ml_options
  
         """
-        if not logger:
-            logger = options.get('logger')
-
-        super().__init__(logger)
+    
         self.has_rescaled = False # only once in init
         self.set_ml_options(options,force_reload=True)
-        #self.logger.Debug(1,'WAKANDA FOREVER!!!!!!!!!!!!!!!')
+        self.global_config = global_config
+        #g.logger.Debug(1,'WAKANDA FOREVER!!!!!!!!!!!!!!!')
         
     def get_ml_options(self):
         return self.ml_options
@@ -138,7 +139,7 @@ class DetectSequence(Base):
         self.media = None
         self.ml_overrides = {}
         if force_reload:
-            self.logger.Debug (1, "Resetting models, will be loaded on next run")
+            g.logger.Debug (1, "Resetting models, will be loaded on next run")
             self.models = {}
 
 
@@ -146,7 +147,7 @@ class DetectSequence(Base):
         #print (f'***** {sequences}')
         if not sequences:
             sequences = self.model_sequence
-        self.logger.Debug (3, "load_models (just init, actual load happens at first detect): {}".format(sequences))
+        g.logger.Debug (3, "load_models (just init, actual load happens at first detect): {}".format(sequences))
         for seq in sequences:
             try:
                 if seq == 'object':
@@ -155,11 +156,11 @@ class DetectSequence(Base):
                     for obj_seq in self.ml_options.get(seq,{}).get('sequence'):
                         try:
                             obj_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
-                            self.logger.Debug (2,'Initializing model  type:{} with options:{}'.format(seq,obj_seq ))
-                            self.models[seq].append(ObjectDetect.Object(options=obj_seq, logger=self.logger))
+                            g.logger.Debug (2,'Initializing model  type:{} with options:{}'.format(seq,obj_seq ))
+                            self.models[seq].append(ObjectDetect.Object(options=obj_seq))
                         except Exception as e:
-                            self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
-                            self.logger.Debug(2,traceback.format_exc())
+                            g.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
+                            g.logger.Debug(2,traceback.format_exc())
 
                 elif seq == 'face':
                     import pyzm.ml.face as FaceDetect
@@ -167,10 +168,10 @@ class DetectSequence(Base):
                     for face_seq in self.ml_options.get(seq,{}).get('sequence'):
                         try:
                             face_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
-                            self.models[seq].append(FaceDetect.Face(options=face_seq, logger=self.logger))
+                            self.models[seq].append(FaceDetect.Face(options=face_seq,))
                         except Exception as e:
-                            self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
-                            self.logger.Debug(2,traceback.format_exc())
+                            g.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
+                            g.logger.Debug(2,traceback.format_exc())
 
                 elif seq == 'alpr':
                     import pyzm.ml.alpr as AlprDetect
@@ -179,17 +180,17 @@ class DetectSequence(Base):
                         
                         try:
                             alpr_seq['disable_locks'] = self.ml_options.get('general',{}).get('disable_locks', 'no')
-                            self.models[seq].append(AlprDetect.Alpr(options=alpr_seq, logger=self.logger))
+                            self.models[seq].append(AlprDetect.Alpr(options=alpr_seq))
                         except Exception as e:
-                            self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
-                            self.logger.Debug(2,traceback.format_exc())                        
+                            g.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
+                            g.logger.Debug(2,traceback.format_exc())                        
 
                 else:
-                    self.logger.Error ('Invalid model: {}'.format(seq))
+                    g.logger.Error ('Invalid model: {}'.format(seq))
                     raise ValueError ('Invalid model: {}'.format(seq))
             except Exception as e:
-                self.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
-                self.logger.Debug(2,traceback.format_exc())
+                g.logger.Error('Error loading same model variation for {}:{}'.format(seq,e))
+                g.logger.Debug(2,traceback.format_exc())
                 continue            
     
     def _rescale_polygons(self, polygons, xfactor, yfactor):
@@ -201,11 +202,152 @@ class DetectSequence(Base):
                 newy = int(y * yfactor)
                 newp.append((newx, newy))
             newps.append({'name': p['name'], 'value': newp, 'pattern': p['pattern']})
-        self.logger.Debug(3,'resized polygons x={}/y={}: {}'.format(
+        g.logger.Debug(3,'resized polygons x={}/y={}: {}'.format(
             xfactor, yfactor, newps))
         return newps
 
-    def _filter_patterns(self,seq, box,label,conf, polygons):
+    
+    # once all bounding boxes are detected, we check to see if any of them
+    # intersect the polygons, if specified
+    # it also makes sure only patterns specified in detect_pattern are drawn
+    def _process_past_detections(self,m,bbox, label, conf, mid, model_name):
+
+        try:
+            FileNotFoundError
+        except NameError:
+            FileNotFoundError = IOError
+
+        if not mid:
+            g.logger.Debug(1,
+                'Monitor ID not specified, cannot match past detections')
+            return bbox, label, conf
+        image_path = self.global_config.get('image_path') or m.get_options().get('image_path')
+        mon_file = '{}/monitor-{}-data.pkl'.format(image_path,mid)
+        g.logger.Debug(2,'trying to load ' + mon_file)
+        saved_bs=[]
+        saved_ls=[]
+        saved_cs=[]
+        try:
+            fh = open(mon_file, "rb")
+            saved_bs = pickle.load(fh)
+            saved_ls = pickle.load(fh)
+            saved_cs = pickle.load(fh)
+            fh.close()
+        except FileNotFoundError:
+            g.logger.Debug(1,'No history data file found for monitor {}'.format(mid))
+            return bbox, label, conf
+        except EOFError:
+            g.logger.Debug(1,'Empty file found for monitor {}'.format(mid))
+            g.logger.Debug (1,'Going to remove {}'.format(mon_file))
+            try:
+                os.remove(mon_file)
+            except Exception as e:
+                g.logger.Error (f'Could not delete: {e}')
+                pass
+        except Exception as e:
+            g.logger.Error(f'Error in processPastDetection: {e}')
+            #g.logger.Error('Traceback:{}'.format(traceback.format_exc()))
+            return bbox, label, conf
+
+        # load past detection
+        global_use_percent = False
+        global_max_diff_area = 0
+        global_mda = self.global_config.get('past_det_max_diff_area')
+        if global_mda:
+            _m = re.match('(\d+)(px|%)?$', global_mda,re.IGNORECASE)
+            if _m:
+                global_max_diff_area = int(_m.group(1))
+                global_use_percent = True if _m.group(2) is None or _m.group(2) == '%' else False
+            else:
+                g.logger.Error('past_det_max_diff_area misformatted: {}'.format(mda))
+
+
+             # it's very easy to forget to add 'px' when using pixels
+            if global_use_percent and (global_max_diff_area < 0 or global_max_diff_area > 100):
+                g.logger.Error(
+                    'past_det_max_diff_area must be in the range 0-100 when using percentages. Setting to 5%, was {}'
+                    .format(self.global_config.get(label_max_diff_area)))
+                global_max_diff_area=5
+       
+        #g.logger.Debug (1,'loaded past: bbox={}, labels={}'.format(saved_bs, saved_ls));
+        g.logger.Debug (4, 'process_past_detections: Global use_percent:{}, max_diff_area:{}'.format(global_use_percent,global_max_diff_area))
+        new_label = []
+        new_bbox = []
+        new_conf = []
+
+        for idx, b in enumerate(bbox):
+
+            max_diff_area = global_max_diff_area
+            use_percent = global_use_percent
+
+            label_max_diff_area= '{}_past_det_max_diff_area'.format(label[idx])
+            mda = m.get_options().get(label_max_diff_area) or self.global_config.get(label_max_diff_area)
+            if mda:
+                g.logger.Debug(4, 'Found {}={}'.format(label_max_diff_area, mda))
+                _m = re.match('(\d+)(px|%)?$',mda,re.IGNORECASE)
+                if _m:
+                    max_diff_area = int(_m.group(1))
+                    use_percent = True if _m.group(2) is None or _m.group(2) == '%' else False
+                else:
+                    g.logger.Error('{} misformatted: {}'.format(label_max_diff_area,mda))
+
+
+                # it's very easy to forget to add 'px' when using pixels
+                if use_percent and (max_diff_area < 0 or max_diff_area > 100):
+                    g.logger.Error(
+                        '{} must be in the range 0-100 when using percentages. Setting to 5%, was {}'
+                        .format(label_max_diff_area, self.global_config.get(label_max_diff_area)))
+                    max_diff_area = 5
+
+            # iterate list of detections
+            old_b = b
+            it = iter(b)
+            b = list(zip(it, it))
+
+            b.insert(1, (b[1][0], b[0][1]))
+            b.insert(3, (b[0][0], b[2][1]))
+            #g.logger.Debug (1,"Past detection: {}@{}".format(saved_ls[idx],b))
+            #g.logger.Debug (1,'BOBK={}'.format(b))
+            obj = Polygon(b)
+            foundMatch = False
+            for saved_idx, saved_b in enumerate(saved_bs):
+                # compare current detection element with saved list from file
+                if saved_ls[saved_idx] != label[idx]: continue
+                it = iter(saved_b)
+                saved_b = list(zip(it, it))
+                saved_b.insert(1, (saved_b[1][0], saved_b[0][1]))
+                saved_b.insert(3, (saved_b[0][0], saved_b[2][1]))
+                saved_obj = Polygon(saved_b)
+                max_diff_pixels = max_diff_area
+
+                if saved_obj.intersects(obj):
+                    if obj.contains(saved_obj):
+                        diff_area = obj.difference(saved_obj).area
+                        if use_percent:
+                            max_diff_pixels = obj.area * max_diff_area / 100
+                    else:
+                        diff_area = saved_obj.difference(obj).area
+                        if use_percent:
+                            max_diff_pixels = saved_obj.area * max_diff_area / 100
+
+                    if diff_area <= max_diff_pixels:
+                        g.logger.Debug(1,
+                            'past detection {}@{} approximately matches {}@{} removing'
+                            .format(saved_ls[saved_idx], saved_b, label[idx], b))
+                        foundMatch = True
+                        break
+                    else:
+                        g.logger.Debug(4,'Diff area of:{} > max_diff_pixels:{} for {}@{}, allowing it'
+                        .format(diff_area, max_diff_pixels,label[idx], b))
+            if not foundMatch:
+                new_bbox.append(old_b)
+                new_label.append(label[idx])
+                new_conf.append(conf[idx])
+
+        return new_bbox, new_label, new_conf
+
+
+    def _filter_detections(self,m, seq, box,label,conf, polygons, h,w):
         
         # show_prefix
         stripped_labels = label[:]
@@ -219,7 +361,21 @@ class DetectSequence(Base):
 
         #print ("************ POLY={}".format(polygons))
 
-
+        global_max_object_area = 0
+        mds=m.get_options().get('max_detection_size') or self.global_config.get('max_detection_size')
+        if mds:  
+                g.logger.Debug(3,'Max object size found to be: {}'.format(mds))
+                # Let's make sure its the right size
+                _m = re.match('(\d*\.?\d*)(px|%)?$', mds,
+                            re.IGNORECASE)
+                if _m:
+                    global_max_object_area = float(_m.group(1))
+                    if _m.group(2) == '%':
+                        global_max_object_area = float(_m.group(1))/100.0*(h * w)
+                        g.logger.Debug (2,'Converted {}% to {}'.format(_m.group(1), global_max_object_area))
+                else:
+                    g.logger.Error('max_detection_size misformatted: {} - ignoring'.format(
+                        mds))
 
         if not polygons:
             oldh =self.media.image_dimensions()['original'][0]
@@ -232,7 +388,7 @@ class DetectSequence(Base):
                 'pattern': None
 
             })
-            self.logger.Debug(2,'No polygons, adding full image polygon: {}'.format(polygons[0]))
+            g.logger.Debug(2,'No polygons, adding full image polygon: {}'.format(polygons[0]))
 
        #print ("************ RES={}, RESIZE={}".format(self.has_rescaled, self.stream_options))
 
@@ -252,34 +408,55 @@ class DetectSequence(Base):
         new_conf = []
         new_err = []
         for idx,b in enumerate(box):
+            max_object_area = global_max_object_area
+            label_max_object_area= '{}_max_detection_size'.format(label[idx])
+            moa = m.get_options().get(label_max_object_area) or self.global_config.get(label_max_object_area)
+            if moa:
+                g.logger.Debug(4,'Found {}={}'.format(label_max_object_area,moa))
+                # Let's make sure its the right size
+                _m = re.match('(\d*\.?\d*)(px|%)?$', moa,
+                            re.IGNORECASE)
+                if _m:
+                    max_object_area = float(_m.group(1))
+                    if _m.group(2) == '%':
+                        max_object_area = float(_m.group(1))/100.0*(h * w)
+                        g.logger.Debug (2,'Converted {}% to {}'.format(_m.group(1), max_object_area))
+                else:
+                    g.logger.Error('{} misformatted: {} - ignoring'.format(label_max_object_area,
+                        moa))
+
+
             old_b = b
             it = iter(b)
             b = list(zip(it, it))
             b.insert(1, (b[1][0], b[0][1]))
             b.insert(3, (b[0][0], b[2][1]))
             obj = Polygon(b)
+            if obj.area > max_object_area and max_object_area:
+                g.logger.Debug (1,'Ignoring {}@{} as its area of {} > {}'.format(label[idx], b, obj.area, max_object_area))
+                continue
 
             for p in polygons:
                 poly = Polygon(p['value'])
-                self.logger.Debug(3,"intersection: comparing object:{},{} to polygon:{},{}".format(label[idx],obj,p['name'],poly))
+                g.logger.Debug(3,"intersection: comparing object:{},{} to polygon:{},{}".format(label[idx],obj,p['name'],poly))
 
                 if obj.intersects(poly):
                     if  p['pattern']:
-                        self.logger.Debug(3, '{} polygon/zone has its own pattern of {}, using that'.format(p['name'],p['pattern']))
+                        g.logger.Debug(3, '{} polygon/zone has its own pattern of {}, using that'.format(p['name'],p['pattern']))
                         r = re.compile(p['pattern'])
                         match = list(filter(r.match, stripped_labels))
                     else:
                         '''
-                        self.logger.Debug (1,'**********************************')
-                        self.logger.Debug (1,'{}'.format(self.ml_overrides))
-                        self.logger.Debug (1,'**********************************')
+                        g.logger.Debug (1,'**********************************')
+                        g.logger.Debug (1,'{}'.format(self.ml_overrides))
+                        g.logger.Debug (1,'**********************************')
                         '''
                         if self.ml_overrides.get(seq,{}).get('pattern'):
                             match_pattern = self.ml_overrides.get(seq,{}).get('pattern')
-                            self.logger.Debug(2,'Match pattern overridden to {} in ml_overrides'.format(match_pattern))
+                            g.logger.Debug(2,'Match pattern overridden to {} in ml_overrides'.format(match_pattern))
                         else:
                             match_pattern = self.ml_options.get(seq,{}).get('general',{}).get('pattern', '.*')
-                            self.logger.Debug(2,'Using global match pattern: {}'.format(match_pattern))
+                            g.logger.Debug(2,'Using global match pattern: {}'.format(match_pattern))
 
                         r = re.compile(match_pattern)
 
@@ -287,7 +464,7 @@ class DetectSequence(Base):
 
                     #if label[idx].startswith('face:') or label[idx].startswith('alpr:') or label[idx] in match:
                     if stripped_labels[idx] in match:
-                        self.logger.Debug(3,'{} intersects object:{}[{}]'.format(
+                        g.logger.Debug(3,'{} intersects object:{}[{}]'.format(
                             p['name'], label[idx], b))
                         new_label.append(label[idx])
                         new_bbox.append(old_b)
@@ -295,7 +472,7 @@ class DetectSequence(Base):
                     else:
                         new_err.append(old_b)
 
-                        self.logger.Debug(3,
+                        g.logger.Debug(3,
                             '{} intersects object:{}[{}] but does NOT match your detect pattern filter'
                             .format(p['name'], label[idx], b))
                     doesIntersect = True
@@ -304,7 +481,7 @@ class DetectSequence(Base):
             # out of poly loop
             if not doesIntersect:
                 new_err.append(old_b)
-                self.logger.Info('object:{} at {} does not fall into any polygons, removing...'.
+                g.logger.Info('object:{} at {} does not fall into any polygons, removing...'.
                     format(label[idx], obj))
         # out of primary bbox loop
         #print ("NEW ERR IS {}".format(new_err))
@@ -386,14 +563,14 @@ class DetectSequence(Base):
 
         if len(self.model_sequence) > 1:
             manual_locking = False
-            self.logger.Debug(3,'Using automatic locking as we are switching between models')
+            g.logger.Debug(3,'Using automatic locking as we are switching between models')
         else:
             manual_locking = True
-            self.logger.Debug(3,'Using manual locking as we are only using one model')
+            g.logger.Debug(3,'Using manual locking as we are only using one model')
             for seq in self.model_sequence:
                 self.ml_options[seq]['auto_lock'] = False        
         t = Timer()
-        media = MediaStream(stream,'video', self.stream_options, logger=self.logger )
+        media = MediaStream(stream,'video', self.stream_options )
         self.media = media
 
         polygons = copy.copy(self.stream_options.get('polygons',[]))
@@ -403,12 +580,12 @@ class DetectSequence(Base):
         while self.media.more():
             frame = self.media.read()
             if frame is None:
-                self.logger.Debug(1,'Ran out of frames to read')
+                g.logger.Debug(1,'Ran out of frames to read')
                 break
             #fname = '/tmp/{}.jpg'.format(self.media.get_last_read_frame())
             #print (f'Writing to {fname}')
             #cv2.imwrite( fname ,frame)
-            self.logger.Debug (1, 'perf: Starting for frame:{}'.format(self.media.get_last_read_frame()))
+            g.logger.Debug (1, 'perf: Starting for frame:{}'.format(self.media.get_last_read_frame()))
             _labels_in_frame = []
             _boxes_in_frame = []
             _error_boxes_in_frame = []
@@ -419,14 +596,14 @@ class DetectSequence(Base):
             found = False
             for seq in self.model_sequence:
                 if seq not in self.ml_overrides.get('model_sequence',seq):
-                    self.logger.Debug (1, 'Skipping {} as it was overridden in ml_overrides'.format(seq))
+                    g.logger.Debug (1, 'Skipping {} as it was overridden in ml_overrides'.format(seq))
                     continue
-                self.logger.Debug(1,'============ Frame: {} Running {} model in sequence =================='.format(self.media.get_last_read_frame(),seq))
+                g.logger.Debug(1,'============ Frame: {} Running {} model in sequence =================='.format(self.media.get_last_read_frame(),seq))
                 pre_existing_labels = self.ml_options.get(seq,{}).get('general',{}).get('pre_existing_labels')
                 if pre_existing_labels:
-                    self.logger.Debug(2,'Making sure we have matched one of {} in {} before we proceed'.format(pre_existing_labels, _labels_in_frame))
+                    g.logger.Debug(2,'Making sure we have matched one of {} in {} before we proceed'.format(pre_existing_labels, _labels_in_frame))
                     if not any(x in _labels_in_frame for x in pre_existing_labels):
-                        self.logger.Debug(1,'Did not find pre existing labels, not running model')
+                        g.logger.Debug(1,'Did not find pre existing labels, not running model')
                         continue
 
                 if not self.models.get(seq):
@@ -436,12 +613,12 @@ class DetectSequence(Base):
                             for m in self.models[seq]:
                                 m.acquire_lock()
                     except Exception as e:
-                        self.logger.Error('Error loading model for {}:{}'.format(seq,e))
-                        self.logger.Debug(2,traceback.format_exc())
+                        g.logger.Error('Error loading model for {}:{}'.format(seq,e))
+                        g.logger.Debug(2,traceback.format_exc())
                         continue
 
                 same_model_sequence_strategy = self.ml_options.get(seq,{}).get('general',{}).get('same_model_sequence_strategy', 'first')
-                self.logger.Debug (3,'{} has a same_model_sequence strategy of {}'.format(seq, same_model_sequence_strategy))
+                g.logger.Debug (3,'{} has a same_model_sequence strategy of {}'.format(seq, same_model_sequence_strategy))
                 
                 # start of same model iteration
                 _b_best_in_same_model = []
@@ -452,22 +629,56 @@ class DetectSequence(Base):
                 cnt = 1
                 # For each model, loop across different variations
                 for m in self.models[seq]:
-                    self.logger.Debug(3,'--------- Frame:{} Running variation: #{} -------------'.format(self.media.get_last_read_frame(),cnt))
+                    g.logger.Debug(3,'--------- Frame:{} Running variation: #{} -------------'.format(self.media.get_last_read_frame(),cnt))
                     cnt +=1
                     try:
                         _b,_l,_c = m.detect(image=frame)
-                        self.logger.Debug(4,'This model iteration inside {} found: labels: {},conf:{}'.format(seq, _l, _c))
+                        g.logger.Debug(4,'This model iteration inside {} found: labels: {},conf:{}'.format(seq, _l, _c))
                     except Exception as e:
-                        self.logger.Error ('Error running model: {}'.format(e))
-                        self.logger.Debug(2,traceback.format_exc())
+                        g.logger.Error ('Error running model: {}'.format(e))
+                        g.logger.Debug(2,traceback.format_exc())
                         continue
 
-                     # Now let's make sure the labels match our pattern
-                    _b,_l,_c, _e = self._filter_patterns(seq,_b,_l,_c, polygons)
+                    # Now let's make sure the labels match our pattern
+                    h,w,_ = frame.shape
+                    _b,_l,_c, _e = self._filter_detections(m, seq,_b,_l,_c, polygons, h, w)
                     if _e:
                         _e_best_in_same_model.extend(_e)
                     if not len(_l):
                         continue
+
+                    # Now let's take past detections into consideration 
+                    # let's remove past detections first, if enabled 
+                
+                    #g.logger.Debug(4,'REMOVE ME: Self m options: {}'.format(m.get_options()))
+                    mpd = m.get_options().get('match_past_detections') or self.global_config.get('match_past_detection')
+                    if mpd == 'yes' and self.stream_options.get('mid'):
+                        # point detections to post processed data set
+                        g.logger.Info('Removing matches to past detections for monitor:{}'.format(self.stream_options.get('mid')))
+                        #g.logger.Debug (1,'BEFORE PAST: {}, {}, {}'.format(_b,_l,_c))
+
+                        _b,_l,_c = self._process_past_detections(m,_b, _l, _c, self.stream_options.get('mid'),seq)
+                        #g.logger.Debug (1,'AFTER PAST: {}, {}, {}'.format(_b,_l,_c))
+                        if not len (_l):
+                            continue
+                        
+                        # save current objects for future comparisons
+                        if seq!='face':
+                            g.logger.Debug(1,
+                                'Saving detections for monitor {} for future match'.format(
+                                    self.stream_options.get('mid')))
+                            try:
+                                image_path = self.global_config.get('image_path') or m.get_options().get('image_path')
+                                mon_file = '{}/monitor-{}-data.pkl'.format(image_path,self.stream_options.get('mid'))
+                                f = open(mon_file, "wb")
+                                pickle.dump(_b, f)
+                                pickle.dump(_l, f)
+                                pickle.dump(_c, f)
+                                f.close()
+                            except Exception as e:
+                                g.logger.Error(f'Error writing to {mon_file}, past detections not recorded:{e}')
+
+
                     if  ((same_model_sequence_strategy == 'first') 
                     or ((same_model_sequence_strategy == 'most') and (len(_l) > len(_l_best_in_same_model))) 
                     or ((same_model_sequence_strategy == 'most_unique') and (len(set(_l)) > len(set(_l_best_in_same_model))))):
@@ -478,14 +689,14 @@ class DetectSequence(Base):
                     if _l_best_in_same_model and self.stream_options.get('save_analyzed_frames') and self.media.get_debug_filename():
                             d = self.stream_options.get('save_frames_dir','/tmp')
                             f = '{}/{}-analyzed-{}.jpg'.format(d,self.media.get_debug_filename(), media.get_last_read_frame())
-                            self.logger.Debug (4, 'Saving analyzed frame: {}'.format(f))
+                            g.logger.Debug (4, 'Saving analyzed frame: {}'.format(f))
                             a = utils.draw_bbox(frame,_b_best_in_same_model,_l_best_in_same_model,_c_best_in_same_model,self.stream_options.get('polygons'))
                             for _b in _e_best_in_same_model:
                                 cv2.rectangle(a, (_b[0], _b[1]), (_b[2], _b[3]),
                                     (0,0,255), 1)
                             cv2.imwrite(f,a)
                     if (same_model_sequence_strategy=='first') and len(_b):
-                        self.logger.Debug(3, 'breaking out of same model loop, as matches found and strategy is "first"')
+                        g.logger.Debug(3, 'breaking out of same model loop, as matches found and strategy is "first"')
                         break
                 # end of same model sequence iteration
                 # at this state x_best_in_model contains the best match across 
@@ -498,10 +709,10 @@ class DetectSequence(Base):
                     _error_boxes_in_frame.extend(_e_best_in_same_model)
                     _models_in_frame.append(seq)
                     if (frame_strategy == 'first'):
-                        self.logger.Debug (2, 'Breaking out of main model loop as strategy is first')
+                        g.logger.Debug (2, 'Breaking out of main model loop as strategy is first')
                         break
                 else:
-                    self.logger.Debug(2,'We did not find any {} matches in frame: {}'.format(seq,self.media.get_last_read_frame()))
+                    g.logger.Debug(2,'We did not find any {} matches in frame: {}'.format(seq,self.media.get_last_read_frame()))
 
             # end of primary model sequence
             if found:
@@ -518,7 +729,7 @@ class DetectSequence(Base):
                 )
                 matched_images.append(frame.copy())
                 if (frame_strategy == 'first'):
-                    self.logger.Debug(2,'Frame strategy is first, breaking out of frame loop')
+                    g.logger.Debug(2,'Frame strategy is first, breaking out of frame loop')
                     break
                 
                
@@ -545,7 +756,7 @@ class DetectSequence(Base):
 
         diff_time = t.stop_and_get_ms()
 
-        self.logger.Debug(
+        g.logger.Debug(
             1,'perf: TOTAL detection sequence (with image loads) took: {}  to process {}'.format(diff_time, stream))
         self.media.stop()
 
