@@ -21,28 +21,29 @@ import re
 from pyzm.helpers.Media import MediaStream
 import imutils
 from pyzm.helpers.utils import Timer
+import pyzm.helpers.globals as g
+
 
 g_start =Timer()
 import face_recognition
 g_diff_time = g_start.stop_and_get_ms()
 
 class Face(Base):
-    def __init__(self, logger=None, options={},upsample_times=1, num_jitters=0, model='hog'):
-        super().__init__(logger)
+    def __init__(self, options={},upsample_times=1, num_jitters=0, model='hog'):
         global g_diff_time
-        #self.logger.Debug (4, 'Face init params: {}'.format(options))
+        #g.logger.Debug (4, 'Face init params: {}'.format(options))
 
         if dlib.DLIB_USE_CUDA and dlib.cuda.get_num_devices() >=1 :
             self.processor = 'gpu'
         else:
             self.processor = 'cpu'
 
-        self.logger.Debug(
+        g.logger.Debug(
             1,'perf: processor:{} Face Recognition library load time took: {} '.format(
                 self.processor, g_diff_time))
 
 
-        self.logger.Debug(
+        g.logger.Debug(
             1,'Initializing face recognition with model:{} upsample:{}, jitters:{}'
             .format(model, upsample_times, num_jitters))
 
@@ -65,7 +66,7 @@ class Face(Base):
         #self.lock_name='pyzm_'+self.processor+'_lock'
         self.lock_name='pyzm_uid{}_{}_lock'.format(os.getuid(),self.processor)
         if self.disable_locks == 'no':
-            self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+            g.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
             self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
             
 
@@ -77,15 +78,15 @@ class Face(Base):
             if (os.path.isfile(self.options.get('known_images_path') +
                                '/faces.pickle')):
                 # old version, we no longer want it. begone
-                self.logger.Debug(
+                g.logger.Debug(
                     1,'removing old faces.pickle, we have moved to clustering')
                 os.remove(self.options.get('known_images_path') + '/faces.pickle')
         except Exception as e:
-            self.logger.Error('Error deleting old pickle file: {}'.format(e))
+            g.logger.Error('Error deleting old pickle file: {}'.format(e))
 
         # to increase performance, read encodings from  file
         if (os.path.isfile(encoding_file_name)):
-            self.logger.Debug(
+            g.logger.Debug(
                 1,'pre-trained faces found, using that. If you want to add new images, remove: {}'
                 .format(encoding_file_name))
 
@@ -93,10 +94,10 @@ class Face(Base):
             #self.known_face_names = data["names"]
         else:
             # no encodings, we have to read and train
-            self.logger.Debug(
+            g.logger.Debug(
                 1,'trained file not found, reading from images and doing training...'
             )
-            self.logger.Debug(
+            g.logger.Debug(
                 1,'If you are using a GPU and run out of memory, do the training using zm_train_faces.py. In this case, other models like yolo may already take up a lot of GPU memory'
             )
 
@@ -106,23 +107,26 @@ class Face(Base):
                 self.knn = pickle.load(f)
                 f.close()
         except Exception as e:
-            self.logger.Error ('Error loading KNN model: {}'.format(e))
+            g.logger.Error ('Error loading KNN model: {}'.format(e))
 
 
+    def get_options(self):
+        return self.options
+        
     def acquire_lock(self):
         if self.disable_locks=='yes':
             return
         if self.is_locked:
-            self.logger.Debug (2, '{} portalock already acquired'.format(self.lock_name))
+            g.logger.Debug (2, '{} portalock already acquired'.format(self.lock_name))
             return
         try:
-            self.logger.Debug (2,f'Waiting for {self.lock_name} portalock...')
+            g.logger.Debug (2,f'Waiting for {self.lock_name} portalock...')
             self.lock.acquire()
-            self.logger.Debug (2,f'Got {self.lock_name} lock...')
+            g.logger.Debug (2,f'Got {self.lock_name} lock...')
             self.is_locked = True
 
         except portalocker.AlreadyLocked:
-            self.logger.Error ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
+            g.logger.Error ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
             raise ValueError ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
 
 
@@ -130,11 +134,11 @@ class Face(Base):
         if self.disable_locks=='yes':
             return
         if not self.is_locked:
-            self.logger.Debug (1, '{} portalock already released'.format(self.lock_name))
+            g.logger.Debug (1, '{} portalock already released'.format(self.lock_name))
             return
         self.lock.release()
         self.is_locked = False
-        self.logger.Debug (1,'Released {} portalock'.format(self.lock_name))
+        g.logger.Debug (1,'Released {} portalock'.format(self.lock_name))
 
     def get_classes(self):
         if self.knn:
@@ -157,7 +161,7 @@ class Face(Base):
     def detect(self, image):
       
         Height, Width = image.shape[:2]
-        self.logger.Debug(
+        g.logger.Debug(
             1,'|---------- Face recognition (input image: {}w*{}h) ----------|'.
             format(Width, Height))
 
@@ -167,11 +171,11 @@ class Face(Base):
         max_size = self.options.get('max_size', Width)
         old_image = None
 
-        self.logger.Debug(5, 'Face options={}'.format(self.options))
+        g.logger.Debug(5, 'Face options={}'.format(self.options))
         
         if Width > max_size:
             downscaled = True
-            self.logger.Debug (2, 'Scaling image down to max size: {}'.format(max_size))
+            g.logger.Debug (2, 'Scaling image down to max size: {}'.format(max_size))
             old_image = image.copy()
             image = imutils.resize(image,width=max_size)
             newHeight, newWidth = image.shape[:2]
@@ -199,7 +203,7 @@ class Face(Base):
             number_of_times_to_upsample=self.upsample_times)
 
         diff_time = t.stop_and_get_ms()
-        self.logger.Debug(1,'perf: processor:{} Finding faces took {}'.format(self.processor, diff_time))
+        g.logger.Debug(1,'perf: processor:{} Finding faces took {}'.format(self.processor, diff_time))
 
         t = Timer()
         face_encodings = face_recognition.face_encodings(
@@ -211,7 +215,7 @@ class Face(Base):
             self.release_lock()
 
         diff_time = t.stop_and_get_ms()
-        self.logger.Debug(
+        g.logger.Debug(
             1,'perf: processor:{} Computing face recognition distances took {}'.format(
                 self.processor, diff_time))
 
@@ -220,30 +224,30 @@ class Face(Base):
 
         # Use the KNN model to find the best matches for the test face
       
-        self.logger.Debug(3,'Comparing to known faces...')
+        g.logger.Debug(3,'Comparing to known faces...')
 
         t = Timer()
         if self.knn:
-            #self.logger.Debug(5, 'FACE ENCODINGS={}'.format(face_encodings))
+            #g.logger.Debug(5, 'FACE ENCODINGS={}'.format(face_encodings))
             closest_distances = self.knn.kneighbors(face_encodings, n_neighbors=1)
-            self.logger.Debug(5, 'Closest knn match indexes (lesser is better): {}'.format(closest_distances))
+            g.logger.Debug(5, 'Closest knn match indexes (lesser is better): {}'.format(closest_distances))
             are_matches = [
                 closest_distances[0][i][0] <= float(self.options.get('face_recog_dist_threshold',0.6))
                 for i in range(len(face_locations))
                 
             ]
             prediction_labels = self.knn.predict(face_encodings)
-            #self.logger.Debug(5, 'KNN predictions: {} are_matches: {}'.format(prediction_labels, are_matches))
+            #g.logger.Debug(5, 'KNN predictions: {} are_matches: {}'.format(prediction_labels, are_matches))
 
         else:
             # There were no faces to compare
             # create a set of non matches for each face found
             are_matches = [False] * len(face_locations)
             prediction_labels = [''] * len(face_locations)
-            self.logger.Debug (1,'No faces to match, so creating empty set')
+            g.logger.Debug (1,'No faces to match, so creating empty set')
 
         diff_time = t.stop_and_get_ms()
-        self.logger.Debug(
+        g.logger.Debug(
             1,'perf: processor:{} Matching recognized faces to known faces took {}'.
             format(self.processor, diff_time))
 
@@ -252,7 +256,7 @@ class Face(Base):
 
 
         if downscaled:
-            self.logger.Debug (2,'Scaling image back up to {}'.format(Width))
+            g.logger.Debug (2,'Scaling image back up to {}'.format(Width))
             image = old_image
             new_face_locations = []
             for loc in face_locations:
@@ -280,7 +284,7 @@ class Face(Base):
                 timestr = time.strftime("%b%d-%Hh%Mm%Ss-")
                 unf = self.options.get('unknown_images_path') + '/' + timestr + str(
                     uuid.uuid4()) + '.jpg'
-                self.logger.Info(
+                g.logger.Info(
                     'Saving cropped unknown face at [{},{},{},{} - includes leeway of {}px] to {}'
                     .format(x1, y1, x2, y2,
                             self.options.get('save_unknown_faces_leeway_pixels'), unf))
@@ -292,5 +296,5 @@ class Face(Base):
             #matched_face_names.append('face:{}'.format(label))
             conf.append(1)
 
-        self.logger.Debug(3,f'FACE:Returning: {matched_face_rects}, {matched_face_names}, {conf}')
+        g.logger.Debug(3,f'FACE:Returning: {matched_face_rects}, {matched_face_names}, {conf}')
         return matched_face_rects, matched_face_names, conf
